set autoscale
set terminal postscript eps enhanced "Helvetica" 16 dashlength 1 color size 8. cm, 6. cm lw 1.5
set output "concrete_fcm_st_5.eps"
unset log
unset label
   unset title 
   set xtic 5.e-4
   set ytic 1.
   set xlabel"strain [-]"
   set ylabel"stress [MPa]"
   set key font ",15" spacing 1.2
   set key top left
   set grid
   set xr [0: 2e-3]		
   set yr [0: 2.4]	
#
#
elem = 0.1;
# w = eps * h;
#
ft = 2.0
gf = 100.e-6
E = 20000.
#
#
wf_lin = 2.*gf/ft
#
linear(w) = w>wf_lin ? 0 : ft - ft * w/wf_lin
#
# %%%%%%%%%%%%%%%%%%%%%%%%
#
wf_exp = gf/ft
#
exponential(w) = ft * exp(-w/wf_exp)
#
# %%%%%%%%%%%%%%%%%%%%%%%%
#
c1 = 3.
c2 = 6.93
wc = 5.14 * gf / ft
#
hordijk(w) = ft * ( (1. + (c1*w/wc)**3 ) * exp(-c2 * w/wc ) - w/wc * (1.+c1**3) * exp(-c2)  )
#
# %%%%%%%%%%%%%%%%%%%%%%%%
#
#
w0 = 0.
w1 = 2e-5
w2 = 4e-5
w3 = 15e-5
red0 = 1
red1 = 0.5
red2 = 0.3
red3 = 0.1
#
red(w) = w < w1 ? red0-(red0-red1)/(w1-w0)*(w-w0) : ( w < w2  ? red1-(red1-red2)/(w2-w1)*(w-w1) : (  w < w3  ? red2-(red2-red3)/(w3-w2)*(w-w2) : 0  ) )
#
#
UDF(w) = red(w) * ft 
#
#
# %%%%%%%%%%%%%%%%%%%%%%%%
#
eps_f = 1.e-2
H = 100.
hardening(eps) = eps > eps_f ? 0 : ft + H * eps
#
f(x) = hardening(x/elem)
#
# total strain = elastic strain + cracking strain = stress / stiffness + crack width / element size
g(x) = f(x) / E + x / elem
#
#
set parametric
#plot [0:2*wf_lin] g(t), f(t) notitle with lines lt 1 lc 7 lw 3,\
#
plot [0:0.0002] g(t), f(t) notitle with lines lt 1 lc 7 lw 3,\
"-" notitle with lines lt 1 lc 7 lw 3,\
'output.dat' using ($2):($3) notitle with points lc 8 pt 6 ps 0.3
0 0
1e-4 2
e

