set autoscale
set terminal postscript eps enhanced "Helvetica" 16 dashlength 1 color size 8. cm, 6. cm lw 1.5
set output "concrete_fcm_st_6.eps"
unset log
unset label
   unset title 
   set xtic 0.1
   set ytic 1.
   set y2tic 50.
   set xlabel"w [mm]"
   set ylabel"stress [MPa]"
   set key font ",15" spacing 1.2
   set key top left
   set y2tics border
   set y2label "fracture energy [N/m]"
   set grid
   set xr [0: 0.3]		
   set yr [0: 2.4]	
   set y2r [0: 120]
#
#
elem = 0.1;
# w = eps * h;
#
ft = 2.0
gf = 100.e-6
E = 20000.
#
#
wf_lin = 2.*gf/ft
#
linear(w) = w>wf_lin ? 0 : ft - ft * w/wf_lin
#
# %%%%%%%%%%%%%%%%%%%%%%%%
#
wf_exp = gf/ft
#
exponential(w) = ft * exp(-w/wf_exp)
#
# %%%%%%%%%%%%%%%%%%%%%%%%
#
c1 = 3.
c2 = 6.93
wc = 5.14 * gf / ft
#
hordijk(w) = w>wc? 0: ft * ( (1. + (c1*w/wc)**3 ) * exp(-c2 * w/wc ) - w/wc * (1.+c1**3) * exp(-c2)  )
#
# %%%%%%%%%%%%%%%%%%%%%%%%
#
w0 = 0.
w1 = 2e-5
w2 = 4e-5
w3 = 15e-5
red0 = 1
red1 = 0.5
red2 = 0.3
red3 = 0.1
#
red(w) = w < w1 ? red0-(red0-red1)/(w1-w0)*(w-w0) : ( w < w2  ? red1-(red1-red2)/(w2-w1)*(w-w1) : (  w < w3  ? red2-(red2-red3)/(w3-w2)*(w-w2) : 0.  ) )
#
UDF(w) = red(w) * ft
#
#
# %%%%%%%%%%%%%%%%%%%%%%%%
#
eps_f = 1.e-2
H = 100.
hardening(eps) = eps > eps_f ? 0 : ft + H * eps
#
# %%%%%%%%%%%%%%%%%%%%%%%%
#
eps0 = 0.
eps1 = 1e-4
eps2 = 2e-4
eps3 = 1e-3
redeps0 = 1
redeps1 = 0.5
redeps2 = 0.3
redeps3 = 0.1
#
red_eps(eps) = eps < eps1 ? redeps0-(redeps0-redeps1)/(eps1-eps0)*(eps-eps0) : ( eps < eps2  ? redeps1-(redeps1-redeps2)/(eps2-eps1)*(eps-eps1) : (  eps < eps3  ? redeps2-(redeps2-redeps3)/(eps3-eps2)*(eps-eps2) : 0.  ) )
#
UDF_eps(eps) = red_eps(eps) * ft
#
f(x) = UDF_eps(x/elem)
#
#
intfAux1(a,x,h)=(x>a?(f(x)-f(a))*h+intfAux1(a,x-h,h):0);
intfAux2(a,x,h)=(x<a?(f(x)-f(a))*h+intfAux2(a,x+h,h):0);
intf(a,x)=x>a?intfAux1(a,x-abs(x-a)/90./2,abs(x-a)/90.)+f(a)*(x-a):-intfAux2(a,x+abs(x-a)/90./2,abs(x-a)/90.)+f(a)*(x-a);
#
plot [x= 0 to 0.3] f(x/1000.) notitle with lines lt 1 lc 7 lw 3,\
'output.dat' using ( ($2-$3/E)*elem * 1000. ):($3) notitle with points lc 8 pt 6 ps 0.3,\
(intf(0,x/1000.)*1e6 ) notitle with lines lt 1 lc 3 lw 2 axes x1y2