set autoscale
set terminal postscript eps enhanced "Helvetica" 16 dashlength 1 color size 8. cm, 6. cm lw 1.5
set output "frcfcm_7_CAF_fibre_orientation_no_snubbing.eps"
unset log
unset label
   unset title 
   set xtic 0.05
   set ytic 5.
   set xlabel"w [mm]"
   set ylabel"stress [MPa]"
   set key font ",15" spacing 1.2
   set key top left
   set grid
   set xr [0: 0.1]		
   set yr [-5: 10.]	
#
set samples  1000
#
elem = 0.1;
# w = eps * h;
#
# MATRIX
#
ft = 2.0
gf = 20.e-6
E = 20000.
#
# FIBERS
   f = 0.
   g = 2. * (1. + exp (pi * f/2.) ) / (4. + f*f) 
   Lf = 12.e-3
   Df = 0.04e-3
   Vf = 0.02
   tau0 = 1.
   Ef = 20.e3
   Gf = 1000.
   eta = Ef * Vf / (E * (1.-Vf) ) 
   w_star = Lf * Lf * tau0 / ( (1. + eta) * Ef * Df )
#   
# Kabele smyk:
#
	b1 = 0.00297262
	b2 = -2.366012e-4
	b3 = 2.17352e-6
#
	tau_s(w) = tau0 * ( 1. + b1 * (w/Df) + b2 * (w/Df)*(w/Df) + b3 * (w/Df)*(w/Df)*(w/Df) );
#
wf_lin = 2.*gf/ft
#
linear(w) = w>wf_lin ? 0 : ft - ft * w/wf_lin
#
# %%%%%%%%%%%%%%%%%%%%%%%%
#
wf_exp = gf/ft
#
exponential(w) = ft * exp(-w/wf_exp)
#
# %%%%%%%%%%%%%%%%%%%%%%%%
#
c1 = 3.
c2 = 6.93
wc = 5.14 * gf / ft
#
hordijk(w) = ft * ( (1. + (c1*w/wc)**3 ) * exp(-c2 * w/wc ) - w/wc * (1.+c1**3) * exp(-c2)  )
#
# %%%%%%%%%%%%%%%%%%%%%%%%
#
##### FIBERS ####
#
theta = pi/3.;
friction = cos(theta) * exp(theta*f);
#
CAF(w) = Vf * sqrt ( w/2. * Ef * (1. + eta) * 8. * tau0 / Df );
CAF_inclined(w) = Vf * sqrt ( w/2. * Ef * (1. + eta) * 8. * tau0 / Df ) * cos(theta) * exp(theta * f);
#
#
SAF(w) = w < w_star ? Vf * (sqrt (4. * Ef * (1+eta) * w * tau0 / Df ) - Ef * (1+eta) * w / Lf) * friction : Vf * Lf / Df * tau0 * (1. - 2.*w / Lf ) * (1. - 2.*w / Lf ) * friction;
#
#
SRF(w) = w < w_star ? g * Vf * Lf / ( 2. * Df ) * tau0 * ( 2. * sqrt( w / w_star)  - w / w_star ) : g * Vf * Lf / ( 2. * Df ) * tau0 * (1. - 2.*w / Lf ) * (1. - 2.*w / Lf )	
#
#
activation_opening = 0.e-6
#
FRC(w) = w > 0. ? CAF(w) : 0.;
FRC_inclined(w) = w > 0. ? CAF_inclined(w) : 0.;
#
composite(x) = x < 0 ? -1e6 : FRC(x-activation_opening) + (1.-Vf) * linear(x)
composite_inclined(x) = x < 0 ? -1e6 : FRC_inclined(x-activation_opening) + (1.-Vf) * linear(x)
#
E_composite = E * (1.-Vf) + Ef * Vf;
#
#
plot [x= 0. to 0.1] composite(x/1000.) notitle with lines lt 3 lc 6 lw 1 dt 2,\
 composite_inclined(x/1000.) notitle with lines lt 1 lc 7 lw 3,\
'output.dat' using ( ($2-$3/E_composite)*elem * 1000. ):($3) notitle with linespoints lc 8 pt 6 ps 0.3

