set autoscale
set terminal postscript eps enhanced "Helvetica" 16 dashlength 1 color size 8. cm, 6. cm lw 1.5
set output "frcfcm_8_CAF_activation_opening_smooth.eps"
unset log
unset label
   unset title 
   set xtic 0.05
   set ytic 5.
   set xlabel"w [mm]"
   set ylabel"stress [MPa]"
   set key font ",15" spacing 1.2
   set key top left
   set grid
   set xr [0: 0.1]		
   set yr [-5: 10.]	
#
set samples 1000
#
elem = 0.1;
# w = eps * h;
#
# MATRIX
#
ft = 2.0
gf = 10.e-6
E = 20000.
#
# FIBERS
   f = 0.7
   g = 2. * (1. + exp (pi * f/2.) ) / (4. + f*f) 
   Lf = 12.e-3
   Df = 0.04e-3
   Vf = 0.02
   tau0 = 1.
   Ef = 20.e3
   Gf = 1000.
   eta = Ef * Vf / (E * (1.-Vf) ) 
   w_star = Lf * Lf * tau0 / ( (1. + eta) * Ef * Df )
#   
# Kabele smyk:
#
	b1 = 0.00297262
	b2 = -2.366012e-4
	b3 = 2.17352e-6
#
	tau_s(w) = tau0 * ( 1. + b1 * (w/Df) + b2 * (w/Df)*(w/Df) + b3 * (w/Df)*(w/Df)*(w/Df) );
#
wf_lin = 2.*gf/ft
#
linear(w) = w>wf_lin ? 0 : ft - ft * w/wf_lin
#
# %%%%%%%%%%%%%%%%%%%%%%%%
#
wf_exp = gf/ft
#
exponential(w) = ft * exp(-w/wf_exp)
#
# %%%%%%%%%%%%%%%%%%%%%%%%
#
c1 = 3.
c2 = 6.93
wc = 5.14 * gf / ft
#
hordijk(w) = ft * ( (1. + (c1*w/wc)**3 ) * exp(-c2 * w/wc ) - w/wc * (1.+c1**3) * exp(-c2)  )
#
# %%%%%%%%%%%%%%%%%%%%%%%%
#
##### FIBERS ####
#
####################################################
#              CAF
####################################################
theta = 0.;
friction = cos(theta) * exp(theta*f);
#
dw1 = 5.e-6
dw0 = -5.e-6
#
dw_smooth = dw1 - dw0;
#
activation_opening = 10.e-6

#
CAF(w) = Vf * sqrt ( w/2. * Ef * (1. + eta) * 8. * tau0 / Df ) * friction;
#
#
# stress at w = dw1
CAF_dw1 = Vf * sqrt ( dw1/2. * Ef * (1. + eta) * 8. * tau0 / Df ) * friction;
#
# stress derivative at w = dw1
CAF_Dsig_dw1 = Vf * sqrt( Ef * (1. + eta) * tau0 / (Df * dw1) ) * friction;
#
#
CAF_C1 = CAF_Dsig_dw1 / dw_smooth**2 - (2*CAF_dw1) / dw_smooth**3;		
CAF_C2 = (3*CAF_dw1) / dw_smooth**2 - CAF_Dsig_dw1 / dw_smooth;
#
smooth_CAF(w) = CAF_C1* (w-dw0)**3 + CAF_C2*(w-dw0)**2;
#
CAF(w) = Vf * sqrt ( w/2. * Ef * (1. + eta) * 8. * tau0 / Df ) * friction;
#
#
smooth_FRC_CAF(w) = w < dw0 ? 0 : ( w < (dw1) ? smooth_CAF(w) : CAF(w)  );
#
#
#
FRC(w) = w > 0. ? CAF(w) : 0.;
#
composite(x) = x < 0 ? -1e6 : smooth_FRC_CAF(x-activation_opening) + (1.-Vf) * linear(x)
#
E_composite = E * (1.-Vf) + Ef * Vf;
#
#
plot [x= 0. to 0.1] composite(x/1000.) notitle with lines lt 1 lc 7 lw 3,\
'output.dat' using ( ($2-$3/E_composite)*elem * 1000. ):($3) notitle with linespoints lc 8 pt 6 ps 0.3