set autoscale
set terminal postscript eps enhanced "Helvetica" 16 dashlength 1 color size 8. cm, 6. cm lw 1.5
set output "concrete_fcm_shear_strength_collins.eps"
unset log
unset label
   unset title 
   set xtic 2e-4
   set ytic 1.
   set xlabel"shear strain [-]"
   set ylabel"shear stress [MPa]"
   set key font ",15" spacing 1.2
   set key bottom right
   set grid
   set xr [0: 10e-4]		
   set yr [0: 5]	
#
#
elem = 0.1;
# w = eps * h;
#
ft = 2.0
gf = 100.e-6
E = 20000.
nu = 0.2
G = E/(2*(1+nu))
#
beta = 0.8
DII = beta * G / (1-beta)
beta2cracks = 1./(1.+G*(1./DII + 1./DII))
#
#
wf_lin = 2.*gf/ft
#
linear(w) = w>wf_lin ? 0 : ft - ft * w/wf_lin
#
# %%%%%%%%%%%%%%%%%%%%%%%%
#
f(x) = linear(x)
#
#
# SHEAR
# 
tau_elastic(x) = G * x;
tau_beta(x) = G * x * beta;
tau_beta2cracks(x) = G * x * beta2cracks;
#
#
plot [x= 0 to 10e-4]\
tau_elastic(x) title 'elastic'  with lines lt 1 lc 6 dt 2 lw 1.5,\
tau_beta(x) title '1 crack' with lines lt 1 lc 7 lw 2,\
tau_beta2cracks(x) title '2 cracks' with lines lt 1 lc 9 lw 2,\
'output.dat' using ($2):($3) notitle with points lc 8 pt 6 ps 1.0